@@ -2,8 +2,7 @@
 
 // SPDX-License-Identifier: GPL-2.0-or-later
 
-#ifndef KIG_MISC_ARGSPARSER_H
-#define KIG_MISC_ARGSPARSER_H
+#pragma once
 
 #include "../objects/common.h"
 
@@ -93,82 +92,87 @@ class ObjectImpType;
 class ArgsParser
 {
 public:
-  /**
-   * this are some enum values that we return from some functions.
-   */
-  enum { Invalid = 0, Valid = 1, Complete = 2 };
-  struct spec { const ObjectImpType* type; std::string usetext; std::string selectstat; bool onOrThrough;};
+    /**
+     * this are some enum values that we return from some functions.
+     */
+    enum { Invalid = 0, Valid = 1, Complete = 2 };
+    struct spec {
+        const ObjectImpType *type;
+        std::string usetext;
+        std::string selectstat;
+        bool onOrThrough;
+    };
+
 private:
-  /**
-   * the args spec..
-   */
-  std::vector<spec> margs;
+    /**
+     * the args spec..
+     */
+    std::vector<spec> margs;
+
+    spec findSpec(const ObjectImp *o, const Args &parents) const;
 
-  spec findSpec( const ObjectImp* o, const Args& parents ) const;
 public:
-  ArgsParser( const struct spec* args, int n );
-  explicit ArgsParser( const std::vector<spec>& args );
-  ArgsParser();
-  ~ArgsParser();
+    ArgsParser(const struct spec *args, int n);
+    explicit ArgsParser(const std::vector<spec> &args);
+    ArgsParser();
+    ~ArgsParser();
 
-  void initialize( const std::vector<spec>& args );
-  void initialize( const struct spec* args, int n );
+    void initialize(const std::vector<spec> &args);
+    void initialize(const struct spec *args, int n);
 
-  /**
-   * returns a new ArgsParser that wants the same args, except for the
-   * ones of the given type.
-   */
-  ArgsParser without( const ObjectImpType* type ) const;
-  // checks if os matches the argument list this parser should parse.
-  int check( const Args& os ) const;
-  int check( const std::vector<ObjectCalcer*>& os ) const;
-  /**
-   * returns the usetext for the argument that o would be used for,
-   * if sel were used as parents.
-   * \p o should be in \p sel ...
-   */
-  std::string usetext( const ObjectImp* o, const Args& sel ) const;
+    /**
+     * returns a new ArgsParser that wants the same args, except for the
+     * ones of the given type.
+     */
+    ArgsParser without(const ObjectImpType *type) const;
+    // checks if os matches the argument list this parser should parse.
+    int check(const Args &os) const;
+    int check(const std::vector<ObjectCalcer *> &os) const;
+    /**
+     * returns the usetext for the argument that o would be used for,
+     * if sel were used as parents.
+     * \p o should be in \p sel ...
+     */
+    std::string usetext(const ObjectImp *o, const Args &sel) const;
 
-  /**
-   * returns the select statement for the next selectable argument
-   * when the given args are selected.
-   */
-  std::string selectStatement( const Args& sel ) const;
+    /**
+     * returns the select statement for the next selectable argument
+     * when the given args are selected.
+     */
+    std::string selectStatement(const Args &sel) const;
 
-  // this reorders the objects or args so that they are in the same
-  // order as the requested arguments..
-  Args parse( const Args& os ) const;
-  std::vector<ObjectCalcer*> parse( const std::vector<ObjectCalcer*>& os ) const;
+    // this reorders the objects or args so that they are in the same
+    // order as the requested arguments..
+    Args parse(const Args &os) const;
+    std::vector<ObjectCalcer *> parse(const std::vector<ObjectCalcer *> &os) const;
 
-  /**
-   * returns the minimal ObjectImp ID that \p o needs to inherit in order
-   * to be useful..  \p o should be part of \p parents .
-   */
-  const ObjectImpType* impRequirement( const ObjectImp* o, const Args& parents ) const;
+    /**
+     * returns the minimal ObjectImp ID that \p o needs to inherit in order
+     * to be useful..  \p o should be part of \p parents .
+     */
+    const ObjectImpType *impRequirement(const ObjectImp *o, const Args &parents) const;
 
-  /**
-   * Supposing that \p parents would be given as parents, this function
-   * returns whether the returned ObjectImp will be, by construction,
-   * on \p o ( if \p o is a curve ), or through \p o ( if \p o is a point ).
-   */
-  bool isDefinedOnOrThrough( const ObjectImp* o, const Args& parents ) const;
+    /**
+     * Supposing that \p parents would be given as parents, this function
+     * returns whether the returned ObjectImp will be, by construction,
+     * on \p o ( if \p o is a curve ), or through \p o ( if \p o is a point ).
+     */
+    bool isDefinedOnOrThrough(const ObjectImp *o, const Args &parents) const;
 
-  // Checks the args according to this args specification.  If the
-  // objects should never have occurred, then an assertion failure
-  // will happen, if one of the args is invalid, then false will be
-  // returned, if all is fine, then true is returned..
-  // assert that the objects are of the right types, and in the right
-  // order as what would be returned by parse( os )..  If minobjects
-  // is provided, then not all objects are needed, and it is enough if
-  // at least minobjects are available..  Use this for object types
-  // that can calc a temporary example object using less than the
-  // required args.  These args need to be at the end of argsspec +
-  // anyobjsspec.  If minobjects is not provided, then it is assumed
-  // that all args are necessary.
-  bool checkArgs( const std::vector<ObjectCalcer*>& os ) const;
-  bool checkArgs( const std::vector<ObjectCalcer*>& os, uint minobjects ) const;
-  bool checkArgs( const Args& os ) const;
-  bool checkArgs( const Args& os, uint minobjects ) const;
+    // Checks the args according to this args specification.  If the
+    // objects should never have occurred, then an assertion failure
+    // will happen, if one of the args is invalid, then false will be
+    // returned, if all is fine, then true is returned..
+    // assert that the objects are of the right types, and in the right
+    // order as what would be returned by parse( os )..  If minobjects
+    // is provided, then not all objects are needed, and it is enough if
+    // at least minobjects are available..  Use this for object types
+    // that can calc a temporary example object using less than the
+    // required args.  These args need to be at the end of argsspec +
+    // anyobjsspec.  If minobjects is not provided, then it is assumed
+    // that all args are necessary.
+    bool checkArgs(const std::vector<ObjectCalcer *> &os) const;
+    bool checkArgs(const std::vector<ObjectCalcer *> &os, uint minobjects) const;
+    bool checkArgs(const Args &os) const;
+    bool checkArgs(const Args &os, uint minobjects) const;
 };
-
-#endif
